/*
Copyright 2021 The Rama Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"context"
	"time"

	v1 "github.com/oecp/rama/pkg/apis/networking/v1"
	scheme "github.com/oecp/rama/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// IPInstancesGetter has a method to return a IPInstanceInterface.
// A group's client should implement this interface.
type IPInstancesGetter interface {
	IPInstances(namespace string) IPInstanceInterface
}

// IPInstanceInterface has methods to work with IPInstance resources.
type IPInstanceInterface interface {
	Create(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.CreateOptions) (*v1.IPInstance, error)
	Update(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.UpdateOptions) (*v1.IPInstance, error)
	UpdateStatus(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.UpdateOptions) (*v1.IPInstance, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.IPInstance, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.IPInstanceList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.IPInstance, err error)
	IPInstanceExpansion
}

// iPInstances implements IPInstanceInterface
type iPInstances struct {
	client rest.Interface
	ns     string
}

// newIPInstances returns a IPInstances
func newIPInstances(c *NetworkingV1Client, namespace string) *iPInstances {
	return &iPInstances{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the iPInstance, and returns the corresponding iPInstance object, and an error if there is any.
func (c *iPInstances) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.IPInstance, err error) {
	result = &v1.IPInstance{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("ipinstances").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of IPInstances that match those selectors.
func (c *iPInstances) List(ctx context.Context, opts metav1.ListOptions) (result *v1.IPInstanceList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.IPInstanceList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("ipinstances").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested iPInstances.
func (c *iPInstances) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("ipinstances").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a iPInstance and creates it.  Returns the server's representation of the iPInstance, and an error, if there is any.
func (c *iPInstances) Create(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.CreateOptions) (result *v1.IPInstance, err error) {
	result = &v1.IPInstance{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("ipinstances").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(iPInstance).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a iPInstance and updates it. Returns the server's representation of the iPInstance, and an error, if there is any.
func (c *iPInstances) Update(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.UpdateOptions) (result *v1.IPInstance, err error) {
	result = &v1.IPInstance{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("ipinstances").
		Name(iPInstance.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(iPInstance).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *iPInstances) UpdateStatus(ctx context.Context, iPInstance *v1.IPInstance, opts metav1.UpdateOptions) (result *v1.IPInstance, err error) {
	result = &v1.IPInstance{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("ipinstances").
		Name(iPInstance.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(iPInstance).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the iPInstance and deletes it. Returns an error if one occurs.
func (c *iPInstances) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("ipinstances").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *iPInstances) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("ipinstances").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched iPInstance.
func (c *iPInstances) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.IPInstance, err error) {
	result = &v1.IPInstance{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("ipinstances").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
